      SUBROUTINE LPGEOM
*.
*...LPGEOM   Define GEANT geometries for the large prototype detector
*.
*. SEQUENCE  : GCCUTS GCONST GCFLAG GCLIST
*.           : GMMATM LPCGEO RCREP  XECGEO XECPMT
*. CALLS     : GGCLOS GMMATE GMTMED GSATT  GSPOS  GSPOSP GSROTM GSVOLU
*.           : USGEOM XEGINI XEGPMT
*. CALLED    : UGINIT
*.
*. BANKS L   : None
*. BANKS U   : None
*.
*. AUTHOR    : T.Mashimo
*. VERSION   : 1.03
*. CREATED   : 06-May-00
*. LAST MOD  : 06-Sep-01
*.
*. Modification Log.
*. 21-Apr-03   R.Sawada        (V1.09) Modified holder ,tip tube, filler
*. 04-Apr-03   R.Sawada        (V1.08) Added Filler
*. 25-Jan-03   R.Sawada        (V1.07) Added Am source plate
*. 23-Jan-03   R.Sawada        (V1.06) Enabled to change distnace between
*.                              honeycomb and holer
*. 22-Jan-03   R.Sawada        (V1.05) Added realistic honeycomb core
*. 22-Jan-03   R.Sawada        (V1.04) Modified the arrangement of XELQ
*. 06-Sep-01   W.Ootani        (V1.03) Take account of liquid xenon
*.                             surface
*. 22-May-00   T.Mashimo       (V1.02) LPTMED,'LQXE' -> GMTMED,'XELQ'.
*. 16-May-00   T.Mashimo       (V1.01) SPxxxx->VPxxxx.  GMTMED->LPTMED.
*.                             Geant initial volume now 'LP  ' instead
*.                             of 'MEG '.
*. 06-May-00   T.Mashimo       (V1.00) First version.
*.
*.**********************************************************************
*.
#include "declare.inc"
#include "geant321/gconst.inc"
#include "geant321/gccuts.inc"
#include "geant321/gcflag.inc"
#include "geant321/gclist.inc"
#include "rcrep.inc"
#include "gmmatm.inc"
#include "lpcgeo.inc"
#include "xecgeo.inc"
#include "xecpmt.inc"
#include "lpflag.inc"
*
      LOGICAL INIT
      SAVE    INIT
      INTEGER IUCOMP
      EXTERNAL IUCOMP
*     
      REAL    VPXEVA(3), VPXELQ(3)
      REAL    VPXPH1(3), VPXPH2(3), VPXPH3(3)
      REAL    VPXPHL(3,3)
      REAL    VPXFIL(3),VPXFIX(3),VPTIP(3),VPTPVA(3)
      EQUIVALENCE (VPXPH1(1), VPXPHL(1,1))
      EQUIVALENCE (VPXPH2(1), VPXPHL(1,2))
      EQUIVALENCE (VPXPH3(1), VPXPHL(1,3))
      REAL    VPXEHP(3), VPXEHC(3), VPXEAW(3), VPXEHV(10)
      REAL    VPAMPL(3), VPAMFM(3)
      REAL    VPXPTP(18)
      REAL    ZPXPTP
      INTEGER IVOL
      REAL DHCCEL , THCCEL
      INTEGER NHCCELX
      INTEGER NHCCELY
      INTEGER IHCCEL
*     
      INTEGER IW, IX, IY, I, IPMT, IHCVAX, IHCVAY, IFILLER
      INTEGER IROT,   IROTAR(6)
      REAL    XPOS0,  YPOS0,  ZPOS0
      REAL    XPOSWD, YPOSWD, ZPOSWD,
     +     XPOSPM, YPOSPM, ZPOSPM,
     +     XPOSFL, YPOSFL, ZPOSFL,
     +     XPOSBS, YPOSBS, ZPOSBS,
     +     XPOSTP, YPOSTP, ZPOSTP,
     +     XPOSHL(3), YPOSHL(3), ZPOSHL(3)
      REAL    ZMXELQ, ZCXELQ, ZMXEVA, ZCXEVA
      REAL    ZPXEHP(2), ZPXEHC, ZPXEAW
*     
      DATA INIT / .FALSE. /
*     
      DATA DHCCEL / 1.27 /
      DATA THCCEL / 0.00508 /
      DATA NHCCELX / 7 /
      DATA NHCCELY / 25/
      DATA VPAMFM / 0., 1.27, 0.0002/
      DATA VPAMPL / 0., 1.27, 0.05 /
      DATA VPXPH1(3), VPXPH2(3), VPXPH3(3) / 1.45, 0.55, 0.25/
      DATA VPXEHP(3), VPXEHC(3) / 0.025, 1.00 /
      DATA VPXEHV / 60., 360., 6, 2, 
     +     -1., 0., 0., 
     +     1., 0., 0./
*     VPXEHV(7) =DHCCEL/SQRT(3.)
*     VPXEHV(10)=DHCCEL/SQRT(3.)
      VPXEHV(7) =DHCCEL/2.
      VPXEHV(10)=DHCCEL/2.
      DATA VPXEAW(3) / 0.05 /
      DATA IROTAR /76, 77, 78, 79, 0, 80 /

      ZPXPTP=0.7
      VPXPTP(1)=0.
      VPXPTP(2)=360.
      VPXPTP(3)=4
      VPXPTP(4)=0.7
      VPXPTP(5)=0.1
      VPXPTP(6)=0.3
      VPXPTP(7)=0.4
      VPXPTP(8)=0.
      VPXPTP(9)=0.3
      VPXPTP(10)=0.25
      VPXPTP(11)=0.
      VPXPTP(12)=0.27
      VPXPTP(13)=0.1
      VPXPTP(14)=0.
      VPXPTP(15)=0.05
      VPXPTP(16)=0.
      VPXPTP(17)=0.
      VPXPTP(18)=0.
*     
      IF (.NOT. INIT) THEN
         INIT = .TRUE.
      END IF
*     
*--   Initialize geometrical parameters in /XECGEO/
*     
      CALL XEGINI
*     
*--   Set up materials
*     
      CALL GMMATE
*     
*--   Set up tracking media
*     
      CALL GMTMED
*     
*--   
*--   Define GEANT volumes
*--   
*     
*     The z=0 is located just in front of the window of the PMTs
*     on the front-side.
*     
      VPLP(1) = PMTINT*FLOAT(NXPMT)
      VPLP(2) = PMTINT*FLOAT(NYPMT)
      VPLP(3) = PMTINT*FLOAT(NZPMT)*1.5
      CALL GSVOLU('LP  ', 'BOX ', TMMEG, VPLP, 3, IVOL)
      IF (IVOL .LE. 0) THEN
         WRITE(CHREP, '(''Error in GSVOLU for LP  :'', I8)') IVOL
         CALL REPORT('LPGEOM', 11, 'ERROR')
      END IF
      CALL GSATT('LP  ', 'SEEN', 0)
*     
*--   Define the geometry of a PMT
*     
      CALL XEGPMT
*     

*
*--   Define Tip tube of a PMT
*
      CALL GSVOLU('XPTP', 'PCON', TMXPGL, VPXPTP, 18, IVOL)
      IF (IVOL .LE. 0) THEN
         WRITE(CHREP, '(''Error in GSVOLU for XPTP:'', I8)') IVOL
         CALL REPORT('XEGPTP', 5, 'ERROR')
      END IF
      CALL GSATT('XPTP', 'SEEN', 1)

*
*--   Define the geometry of PMT holder plates
*     
      CALL GSVOLU('XPH1', 'BOX ', TMXPBS, VPXPH1, 0, IVOL)
      IF (IVOL .LE. 0) THEN
         WRITE(CHREP, '(''Error in GSVOLU for XPH1:'', I8)') IVOL
         CALL REPORT('LPGEOM', 12, 'ERROR')
      END IF
      CALL GSATT('XPWD', 'SEEN', 1)
*     
      CALL GSVOLU('XPH2', 'BOX ', TMXACR, VPXPH2, 0, IVOL)
      IF (IVOL .LE. 0) THEN
         WRITE(CHREP, '(''Error in GSVOLU for XPH2:'', I8)') IVOL
         CALL REPORT('LPGEOM', 13, 'ERROR')
      END IF
      CALL GSATT('XPWD', 'SEEN', 1)
*     
      CALL GSVOLU('XPH3', 'BOX ', TMXACR, VPXPH3, 0, IVOL)
      IF (IVOL .LE. 0) THEN
         WRITE(CHREP, '(''Error in GSVOLU for XPH3:'', I8)') IVOL
         CALL REPORT('LPGEOM', 14, 'ERROR')
      END IF
      CALL GSATT('XPWD', 'SEEN', 1)
*
*
*-- We can now fix the size of the vacuum volume
*     
*
      ZMXELQ = -2*(VPXPWD(3)+VPXPH1(3)+VPXPH2(3)+VPXPH3(3))
      ZMXEVA = ZMXELQ - 4.*VPXEHP(3) - 2.*VPXEHC(3) - 5.0  - ZXEEXP
      VPXEVA(1) = PMTINT*FLOAT(NXPMT)/2. + ABS(ZMXEVA)
      VPXEVA(2) = PMTINT*FLOAT(NYPMT)/2. + ABS(ZMXEVA)
      VPXEVA(3) = PMTINT*FLOAT(NZPMT)/2. + ABS(ZMXEVA) + ZXEEXP/2.
      ZCXEVA = ZMXEVA + VPXEVA(3)
      CALL GSVOLU('XEVA', 'BOX ', TMXEVA, VPXEVA, 3, IVOL)
      IF (IVOL .LE. 0) THEN
         WRITE(CHREP, '(''Error in GSVOLU for XEVA:'', I8)') IVOL
         CALL REPORT('LPGEOM', 16, 'ERROR')
      END IF
      CALL GSATT('XEVA', 'SEEN', 0)
      CALL GSPOS('XEVA', 1, 'LP  ',
     +           0., 0., ZCXEVA , 0, 'ONLY')

*
*-- Honeycomb window and Al window
*
      VPXEHP(1) = PMTINT*FLOAT(NXPMT)/2.
      VPXEHP(2) = PMTINT*FLOAT(NYPMT)/2.
      CALL GSVOLU('XEHP', 'BOX ', TMXEHP, VPXEHP, 3, IVOL)
      IF (IVOL .LE. 0) THEN
         WRITE(CHREP, '(''Error in GSVOLU for XEHP:'', I8)') IVOL
         CALL REPORT('LPGEOM', 17, 'ERROR')
      END IF
      CALL GSATT('XEHP', 'SEEN', 1)
      ZPXEHP(2) = ZMXELQ - VPXEHP(3)
      CALL GSPOS('XEHP', 1, 'XEVA',
     +           0., 0.,  -ZCXEVA +  ZPXEHP(2) - ZXEEXP, 0, 'ONLY')
*
      IF(HCRLON .EQ. 1) THEN
         VPXEHC(1) = PMTINT*FLOAT(NXPMT)/2.
         VPXEHC(2) = PMTINT*FLOAT(NYPMT)/2.
         CALL GSVOLU('XEHC', 'BOX ', TMHCPL, VPXEHC, 3, IVOL)
         IF (IVOL .LE. 0) THEN
            WRITE(CHREP, '(''Error in GSVOLU for XEHC:'', I8)') IVOL
            CALL REPORT('LPGEOM', 18, 'ERROR')
         END IF
         CALL GSATT('XEHC', 'SEEN', 1)
         ZPXEHC = ZPXEHP(2) - VPXEHP(3) - VPXEHC(3)
         CALL GSPOS('XEHC', 1, 'XEVA',
     +        0., 0., -ZCXEVA + ZPXEHC -ZXEEXP, 0, 'MANY')
         CALL GSVOLU('HCVA', 'PGON', TMHCVA, VPXEHV, 10, IVOL)
         IF (IVOL .LE. 0) THEN
            WRITE(CHREP, '(''Error in GSVOLU for HCVA:'', I8)') IVOL
            CALL REPORT('LPGEOM', 19, 'ERROR')
         END IF
         CALL GSATT('HCVA', 'SEEN', 1)
       
*         CALL GSROTM(75,  90.,  30.,   90.,   120.,  0.,   0.)
         IROT = 0
         IHCCEL = 1
         DO 6 IHCVAY=1,NHCCELY 
            IF((IHCVAY-2*(IHCVAY/2)) .EQ. 0) THEN
               DO 2 IHCVAX=1,NHCCELX
                  CALL GSPOS('HCVA', IHCCEL, 'XEVA',
     +                 (IHCVAX-1-NHCCELX/2)
     +                 *SQRT(3.*(DHCCEL**2)+4.*DHCCEL*THCCEL)  + HCX ,
     +                 (IHCVAY-1-NHCCELY/2)*(DHCCEL/2.+THCCEL )+ HCY ,
     +                 -ZCXEVA + ZPXEHC - ZXEEXP, IROT, 'ONLY')
                  IHCCEL = IHCCEL +1
 2             CONTINUE
            ELSE
               DO 4 IHCVAX=1,NHCCELX-1
                  CALL GSPOS('HCVA', IHCCEL, 'XEVA',
     +                 (IHCVAX-1-NHCCELX/2+0.5)
     +                 *SQRT(3.*(DHCCEL**2)+4.*DHCCEL*THCCEL)  + HCX,
     +                 (IHCVAY-1-NHCCELY/2)*(DHCCEL/2.+THCCEL) + HCY ,
     +                 -ZCXEVA + ZPXEHC - ZXEEXP, IROT, 'ONLY')
                  IHCCEL = IHCCEL +1
 4             CONTINUE
            END IF
 6       CONTINUE
      ELSE
         VPXEHC(1) = PMTINT*FLOAT(NXPMT)/2.
         VPXEHC(2) = PMTINT*FLOAT(NYPMT)/2.
         CALL GSVOLU('XEHC', 'BOX ', TMXEHC, VPXEHC, 3, IVOL)
         IF (IVOL .LE. 0) THEN
            WRITE(CHREP, '(''Error in GSVOLU for XEHC:'', I8)') IVOL
            CALL REPORT('LPGEOM', 18, 'ERROR')
         END IF
         CALL GSATT('XEHC', 'SEEN', 1)
         ZPXEHC = ZPXEHP(2) - VPXEHP(3) - VPXEHC(3)
         CALL GSPOS('XEHC', 1, 'XEVA',
     +        0., 0., -ZCXEVA + ZPXEHC - ZXEEXP, 0, 'ONLY')
      END IF
*
      ZPXEHP(1) = ZPXEHC - VPXEHC(3) - VPXEHP(3)
      CALL GSPOS('XEHP', 2, 'XEVA',
     +           0., 0., -ZCXEVA + ZPXEHP(1) -ZXEEXP, 0, 'ONLY')
*
      VPXEAW(1) = PMTINT*FLOAT(NXPMT)/2.
      VPXEAW(2) = PMTINT*FLOAT(NYPMT)/2.
      CALL GSVOLU('XEAW', 'BOX ', TMXEAW, VPXEAW, 3, IVOL)
      IF (IVOL .LE. 0) THEN
         WRITE(CHREP, '(''Error in GSVOLU for XEAW:'', I8)') IVOL
         CALL REPORT('LPGEOM', 19, 'ERROR')
      END IF
      CALL GSATT('XEAW', 'SEEN', 1)
      ZPXEAW = ZPXEHP(1) - VPXEHP(3) - 5.0 - VPXEAW(3)
      CALL GSPOS('XEAW', 1, 'LP  ',
     +           0., 0., ZPXEAW -ZXEEXP,
     +           0, 'ONLY')


*__   Filler and Xenon before front face PMTs
      
      VPXFIL(1) = 0. 
      VPXFIL(2) = 2.35
      VPXFIL(3) = VPXPH1(3)+VPXPH2(3)-VPXPMT(3)
      VPXFIX(1) = 0. 
      VPXFIX(2) = 2.4
      VPXFIX(3) = VPXPH1(3)+VPXPH2(3)-VPXPMT(3)
      ZPOSFL = -2.*VPXPWD(3) - 2.*VPXPMT(3) - VPXFIL(3)
      IF(FILLERON .EQ. 1) THEN
         CALL GSVOLU('FILL', 'TUBE', TMXFIL, VPXFIL, 3, IVOL)
         IF (IVOL .LE. 0) THEN
            WRITE(CHREP, '(''Error in GSVOLU for FILL:'', I8)') IVOL
            CALL REPORT('LPGEOM', 12, 'ERROR')
         END IF
         CALL GSATT('FILL', 'SEEN', 1)
         
         IROT = IROTAR(5)
         IFILLER = 1
         DO 9 IX = 1, 6
            DO 8 IY = 1, 6
               XPOSFL = (FLOAT(IX)-3.5)*PMTINT
               YPOSFL = (FLOAT(IY)-3.5)*PMTINT
               CALL GSPOS('FILL', IFILLER, 'XEVA',
     +              XPOSFL, YPOSFL, ZPOSFL - ZCXEVA, IROT, 'MANY')
               IFILLER = IFILLER +1
 8          CONTINUE
 9       CONTINUE
      END IF
      
      CALL GSVOLU('FILX', 'TUBE', TMXELQ, VPXFIX, 3, IVOL)
      IF (IVOL .LE. 0) THEN
         WRITE(CHREP, '(''Error in GSVOLU for FILX:'', I8)') IVOL
         CALL REPORT('LPGEOM', 12, 'ERROR')
      END IF
      CALL GSATT('FILX', 'SEEN', 1)
      
      IROT = IROTAR(5)
      IFILLER = 1
      DO 11 IX = 1, 6
         DO 10 IY = 1, 6
            XPOSFL = (FLOAT(IX)-3.5)*PMTINT
            YPOSFL = (FLOAT(IY)-3.5)*PMTINT
            CALL GSPOS('FILX', IFILLER, 'XEVA',
     +           XPOSFL, YPOSFL, ZPOSFL - ZCXEVA, IROT, 'MANY')
            IFILLER = IFILLER +1
 10      CONTINUE
 11   CONTINUE

* vacuum in tip tube
      VPTPVA(1)=0
      VPTPVA(2)=0.15
      VPTPVA(3)=0.2
      CALL GSVOLU('TIPV', 'TUBE', TMXEVA, VPTPVA , 3, IVOL)
      IF (IVOL .LE. 0) THEN
         WRITE(CHREP, '(''Error in GSVOLU for TIPV:'', I8)') IVOL
         CALL REPORT('LPGEOM', 12, 'ERROR')
      END IF
      CALL GSATT('TIPV', 'SEEN', 0)
      
      IROT = IROTAR(5)
      IFILLER = 1
      ZPOSFL = -2.*VPXPWD(3) - 2.*VPXPMT(3) - VPTPVA(3)
      DO 13 IX = 1, 6
         DO 12 IY = 1, 6
            XPOSFL = (FLOAT(IX)-3.5)*PMTINT
            YPOSFL = (FLOAT(IY)-3.5)*PMTINT
            CALL GSPOS('TIPV', IFILLER, 'XEVA',
     +           XPOSFL, YPOSFL, ZPOSFL - ZCXEVA, IROT, 'MANY')
            IFILLER = IFILLER +1
 12      CONTINUE
 13   CONTINUE

*
*-- Place PMTs and their holders and G10 base and Tip tube.
*
      CALL GSROTM(76,  90.,  90.,   0.,   0.,  90.,   0.)
      CALL GSROTM(77,  90.,  90., 180.,   0.,  90., 180.)
      CALL GSROTM(78,   0.,   0.,  90.,   0.,  90.,  90.)
      CALL GSROTM(79,   0.,   0.,  90., 180.,  90., 270.)
      CALL GSROTM(80,  90., 180.,  90.,  90., 180.,   0.)
*
      DO 100 IW = 1, NWALL
      IF (IW .EQ. 1 .OR. IW .EQ. 2) THEN
         XPOSWD = -PMTINT*FLOAT(NXPMT)/2. - VPXPWD(3)
         XPOSPM = XPOSWD - VPXPWD(3) - VPXPMT(3)
         XPOSBS = XPOSPM - VPXPMT(3) - VPXPBS(3)
         XPOSTP = XPOSPM - VPXPMT(3) - ZPXPTP
*         XPOSHL(1) = XPOSPM + ZPXPSS - VPXPSS(3) + VPXPHL(3,1)
         XPOSHL(1) = XPOSWD - VPXPWD(3) - VPXPHL(3,1)
         XPOSHL(2) = XPOSHL(1) - VPXPHL(3,1) - VPXPHL(3,2)
         XPOSHL(3) = XPOSHL(2) - VPXPHL(3,2) - VPXPHL(3,3)
         IF (IW .EQ. 2) THEN
            XPOSWD = -XPOSWD
            XPOSPM = -XPOSPM
            XPOSBS = -XPOSBS
            XPOSTP = -XPOSTP
            DO 18 I = 1, 3
 18            XPOSHL(I) = -XPOSHL(I)
         END IF
         YPOS0 = -PMTINT*FLOAT(NYPMT+1)/2.
         ZPOS0 = -PMTINT/2.
         DO 20 I = 1, 3
            VPXPHL(1,I) = PMTINT*FLOAT(NYPMT)/2.
            VPXPHL(2,I) = PMTINT*FLOAT(NZPMT)/2.
            YPOSHL(I) = 0.
            ZPOSHL(I) = PMTINT*FLOAT(NZPMT)/2.
 20      CONTINUE
      ELSE IF (IW .EQ. 3 .OR. IW .EQ. 4) THEN
         YPOSWD = -PMTINT*FLOAT(NYPMT)/2. - VPXPWD(3)
         YPOSPM = YPOSWD - VPXPWD(3) - VPXPMT(3)
         YPOSBS = YPOSPM - VPXPMT(3) - VPXPBS(3)
         YPOSTP = YPOSPM - VPXPMT(3) - ZPXPTP
*         YPOSHL(1) = YPOSPM + ZPXPSS - VPXPSS(3) + VPXPHL(3,1)
         YPOSHL(1) = YPOSWD - VPXPWD(3) - VPXPHL(3,1)
         YPOSHL(2) = YPOSHL(1) - VPXPHL(3,1) - VPXPHL(3,2)
         YPOSHL(3) = YPOSHL(2) - VPXPHL(3,2) - VPXPHL(3,3)
         IF (IW .EQ. 4) THEN
            YPOSWD = -YPOSWD
            YPOSPM = -YPOSPM
            YPOSBS = -YPOSBS
            YPOSTP = -YPOSTP
            DO 30 I = 1, 3
 30         YPOSHL(I) = -YPOSHL(I)
         END IF
         ZPOS0 = -PMTINT/2.
         XPOS0 = -PMTINT*FLOAT(NXPMT+1)/2.
         DO 40 I = 1, 3
            VPXPHL(1,I) = PMTINT*FLOAT(NZPMT)/2.
            VPXPHL(2,I) = PMTINT*FLOAT(NXPMT)/2.
            ZPOSHL(I) = PMTINT*FLOAT(NZPMT)/2.
            XPOSHL(I) = 0.
 40      CONTINUE
      ELSE IF (IW .EQ. 5 .OR. IW .EQ. 6) THEN
         ZPOSWD = -VPXPWD(3)
         ZPOSPM = ZPOSWD - VPXPWD(3) - VPXPMT(3)
         ZPOSBS = ZPOSPM - VPXPMT(3) - VPXPBS(3)
         ZPOSTP = ZPOSPM - VPXPMT(3) - ZPXPTP
*         ZPOSHL(1) = ZPOSPM + ZPXPSS - VPXPSS(3) + VPXPHL(3,1)
         ZPOSHL(1) = ZPOSWD - VPXPWD(3) -VPXPHL(3,1)
         ZPOSHL(2) = ZPOSHL(1) - VPXPHL(3,1) - VPXPHL(3,2)
         ZPOSHL(3) = ZPOSHL(2) - VPXPHL(3,2) - VPXPHL(3,3)
         IF (IW .EQ. 6) THEN
            ZPOSWD = -ZPOSWD + PMTINT*FLOAT(NZPMT)
            ZPOSPM = -ZPOSPM + PMTINT*FLOAT(NZPMT)
            ZPOSBS = -ZPOSBS + PMTINT*FLOAT(NZPMT)
            ZPOSTP = -ZPOSTP + PMTINT*FLOAT(NZPMT)
            DO 50 I = 1, 3
 50         ZPOSHL(I) = -ZPOSHL(I) + PMTINT*FLOAT(NZPMT)
         END IF
         XPOS0 = -PMTINT*FLOAT(NXPMT+1)/2.
         YPOS0 = -PMTINT*FLOAT(NYPMT+1)/2.
         DO 60 I = 1, 3
            VPXPHL(1,I) = PMTINT*FLOAT(NXPMT)/2.
            VPXPHL(2,I) = PMTINT*FLOAT(NYPMT)/2.
            XPOSHL(I) = 0.
            YPOSHL(I) = 0.
 60      CONTINUE
      END IF

*
      IROT = IROTAR(IW)
      
      CALL GSPOSP('XPH1', IW, 'XEVA',
     +     XPOSHL(1), YPOSHL(1), -ZCXEVA+ZPOSHL(1), IROT, 'MANY',
     +     VPXPHL(1,1), 3)
      CALL GSPOSP('XPH2', IW, 'XEVA',
     +     XPOSHL(2), YPOSHL(2), -ZCXEVA+ZPOSHL(2), IROT, 'MANY',
     +     VPXPHL(1,2), 3)
      CALL GSPOSP('XPH3', IW, 'XEVA',
     +     XPOSHL(3), YPOSHL(3), -ZCXEVA+ZPOSHL(3), IROT, 'MANY',
     +     VPXPHL(1,3), 3)
*     
      
      DO 90 IX = 1, NIJPMT(1,IW)
         DO 80 IY = 1, NIJPMT(2,IW)
            IF (IW .EQ. 1 .OR. IW .EQ. 2) THEN
               YPOSWD = YPOS0 + FLOAT(IX)*PMTINT
               ZPOSWD = ZPOS0 + FLOAT(IY)*PMTINT
               YPOSPM = YPOSWD
               ZPOSPM = ZPOSWD
               YPOSBS = YPOSWD
               ZPOSBS = ZPOSWD
               YPOSTP = YPOSWD
               ZPOSTP = ZPOSWD
            ELSE IF (IW .EQ. 3 .OR. IW .EQ. 4) THEN
               ZPOSWD = ZPOS0 + FLOAT(IX)*PMTINT
               XPOSWD = XPOS0 + FLOAT(IY)*PMTINT
               ZPOSPM = ZPOSWD
               XPOSPM = XPOSWD
               ZPOSBS = ZPOSWD
               XPOSBS = XPOSWD
               ZPOSTP = ZPOSWD
               XPOSTP = XPOSWD
            ELSE IF (IW .EQ. 5 .OR. IW .EQ. 6) THEN
               XPOSWD = XPOS0 + FLOAT(IX)*PMTINT
               YPOSWD = YPOS0 + FLOAT(IY)*PMTINT
               XPOSPM = XPOSWD
               YPOSPM = YPOSWD
               XPOSBS = XPOSWD
               YPOSBS = YPOSWD
               XPOSTP = XPOSWD
               YPOSTP = YPOSWD
            END IF
            IPMT = IX + (IY-1)*IJOFFS(IW) + IWOFFS(IW)
            
            CALL GSPOS('XPWD', IPMT, 'XEVA',
     +           XPOSWD, YPOSWD, -ZCXEVA+ZPOSWD, IROT, 'ONLY')
            CALL GSPOS('XPMT', IPMT, 'XEVA',
     +           XPOSPM, YPOSPM, -ZCXEVA+ZPOSPM, IROT, 'ONLY')
            CALL GSPOS('XPBS', IPMT, 'XEVA',
     +           XPOSBS, YPOSBS, -ZCXEVA+ZPOSBS, IROT, 'ONLY')
            CALL GSPOS('XPTP', IPMT, 'XEVA',
     +           XPOSTP, YPOSTP, -ZCXEVA+ZPOSTP, IROT, 'ONLY')
 80      CONTINUE
 90   CONTINUE
 100  CONTINUE
      
      

*
*-- Place Am source plate
      CALL GSVOLU('AMP1', 'TUBE', TMAMFM, VPAMFM, 3, IVOL)
      IF (IVOL .LE. 0) THEN
         WRITE(CHREP, '(''Error in GSVOLU for AMP1:'', I8)') IVOL
         CALL REPORT('LPGEOM', 12, 'ERROR')
      END IF
      CALL GSATT('AMP1', 'SEEN', 1)
      CALL GSVOLU('AMP2', 'TUBE', TMAMPL, VPAMPL, 3, IVOL)
      IF (IVOL .LE. 0) THEN
         WRITE(CHREP, '(''Error in GSVOLU for AMP2:'', I8)') IVOL
         CALL REPORT('LPGEOM', 12, 'ERROR')
      END IF
      CALL GSATT('AMP2', 'SEEN', 1)
      IROT = IROTAR(3)
      CALL GSPOS('AMP1', 1, 'XEVA',0. ,PALPHA+VPAMFM(3) 
     +     ,-ZCXEVA + 2.*PMTINT  ,IROT, 'ONLY')
      CALL GSPOS('AMP2', 1, 'XEVA',0. ,PALPHA+VPAMFM(3)*2.+VPAMPL(3)
     +     ,-ZCXEVA + 2.*PMTINT  ,IROT, 'ONLY')
      IROT = IROTAR(4)
      CALL GSPOS('AMP1', 2, 'XEVA',0. ,-(PALPHA+VPAMFM(3))
     +     ,-ZCXEVA + 2.*PMTINT ,IROT, 'ONLY')
      CALL GSPOS('AMP2', 2, 'XEVA',0. ,-(PALPHA+VPAMFM(3)*2.+VPAMPL(3))
     +     ,-ZCXEVA + 2.*PMTINT ,IROT, 'ONLY')
      IROT = IROTAR(2)
      CALL GSPOS('AMP1', 3, 'XEVA',PALPHA+VPAMFM(3),0.     
     +     ,-ZCXEVA + 2.*PMTINT ,IROT, 'ONLY')
      CALL GSPOS('AMP2', 3, 'XEVA',PALPHA+VPAMFM(3)*2.+VPAMPL(3),0.     
     +     ,-ZCXEVA + 2.*PMTINT ,IROT, 'ONLY')
      IROT = IROTAR(1)
      CALL GSPOS('AMP1', 4, 'XEVA',-(PALPHA+VPAMFM(3)),0.     
     +     ,-ZCXEVA + 2.*PMTINT ,IROT, 'ONLY')
      CALL GSPOS('AMP2', 4, 'XEVA',-(PALPHA+VPAMFM(3)*2.+VPAMPL(3)),0.     
     +     ,-ZCXEVA + 2.*PMTINT ,IROT, 'ONLY')

*
*-- Place Liquid Xenon

      VPXELQ(1) = (PMTINT*FLOAT(NXPMT)/2. + ABS(ZMXELQ))
      VPXELQ(2) = PMTINT*FLOAT(NYPMT)/2.*LEVEL + ABS(ZMXELQ)/2
      VPXELQ(3) = (PMTINT*FLOAT(NZPMT)/2. + ABS(ZMXELQ)) + ZXEEXP/2.
      
      ZCXELQ = ZMXELQ + VPXELQ(3)
      CALL GSVOLU('XELQ', 'BOX ', TMXELQ, VPXELQ, 3, IVOL)
      IF (IVOL .LE. 0) THEN
         WRITE(CHREP, '(''Error in GSVOLU for XELQ:'', I8)') IVOL
         CALL REPORT('LPGEOM', 15, 'ERROR')
      END IF
      CALL GSATT('XELQ', 'SEEN', 1)

*
      CALL GSPOS('XELQ', 1, 'XEVA',0.,
     +           -PMTINT*FLOAT(NYPMT)/2.*(1-LEVEL)-ABS(ZMXELQ)/2,
     +           -ZCXEVA + ZMXELQ + VPXELQ(3) - ZXEEXP,
     +           0, 'MANY')
*
*-- Call user geometry routine
*
      CALL USGEOM
*
*-- Close geometry banks
*
      CALL GGCLOS
*
*-- Display the geometry
*
*     16-Feb-00  T. Mashimo  The following call to GDTREE has been
*     disabled, since it somehow causes core dump (in ixgetpl_)
*     on a Linux platform.
**    CALL GDTREE('LP  ', 0, 0)
      CALL ICLRWK(0, 0)
*
**    CALL GDSPEC('ECAL')
**    CALL ICLRWK(0, 0)
*
**    CALL GDRAWC('LP  ', 3, 0., 10., 10., 1.0, 1.0)
**    CALL ICLRWK(0, 0)
*
  999 CONTINUE
      RETURN
      END







